==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/VirtualGatewayClientTlsCertificate.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class VirtualGatewayClientTlsCertificate(
    file: Option[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate
    ] = None,
    sds: Option[zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate = {
    import VirtualGatewayClientTlsCertificate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
      .builder()
      .optionallyWith(file.map(value => value.buildAwsValue()))(_.file)
      .optionallyWith(sds.map(value => value.buildAwsValue()))(_.sds)
      .build()
  }
  def asReadOnly
      : zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate.ReadOnly =
    zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate
      .wrap(buildAwsValue())
}
object VirtualGatewayClientTlsCertificate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate =
      zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate(
        file.map(value => value.asEditable),
        sds.map(value => value.asEditable)
      )
    def file: Option[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate.ReadOnly
    ]
    def sds: Option[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate.ReadOnly
    ]
    def getFile: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate.ReadOnly
    ] = AwsError.unwrapOptionField("file", file)
    def getSds: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate.ReadOnly
    ] = AwsError.unwrapOptionField("sds", sds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
  ) extends zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate.ReadOnly {
    override val file: Option[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate.ReadOnly
    ] = scala
      .Option(impl.file())
      .map(value =>
        zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate
          .wrap(value)
      )
    override val sds: Option[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate.ReadOnly
    ] = scala
      .Option(impl.sds())
      .map(value =>
        zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
  ): zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-appmesh_3-5.17.203.1-sources.jar: zio/aws/appmesh/model/VirtualGatewayClientTlsCertificate.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class VirtualGatewayClientTlsCertificate(
    file: Optional[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate
    ] = Optional.Absent,
    sds: Optional[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate = {
    import VirtualGatewayClientTlsCertificate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
      .builder()
      .optionallyWith(file.map(value => value.buildAwsValue()))(_.file)
      .optionallyWith(sds.map(value => value.buildAwsValue()))(_.sds)
      .build()
  }
  def asReadOnly
      : zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate.ReadOnly =
    zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate
      .wrap(buildAwsValue())
}
object VirtualGatewayClientTlsCertificate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate =
      zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate(
        file.map(value => value.asEditable),
        sds.map(value => value.asEditable)
      )
    def file: Optional[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate.ReadOnly
    ]
    def sds: Optional[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate.ReadOnly
    ]
    def getFile: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate.ReadOnly
    ] = AwsError.unwrapOptionField("file", file)
    def getSds: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate.ReadOnly
    ] = AwsError.unwrapOptionField("sds", sds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
  ) extends zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate.ReadOnly {
    override val file: Optional[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.file())
      .map(value =>
        zio.aws.appmesh.model.VirtualGatewayListenerTlsFileCertificate
          .wrap(value)
      )
    override val sds: Optional[
      zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.sds())
      .map(value =>
        zio.aws.appmesh.model.VirtualGatewayListenerTlsSdsCertificate
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayClientTlsCertificate
  ): zio.aws.appmesh.model.VirtualGatewayClientTlsCertificate.ReadOnly =
    new Wrapper(impl)
}
